import {Component, Event, EventEmitter, h, Prop} from '@stencil/core';
import {MonobankLangListInterface, MonobankTopMenuListInterface} from "../../../../../index";

@Component({
  tag: 's-cnt-monobank-top-menu',
  styleUrl: 's-cnt-monobank-top-menu.css',
  shadow: false,
  scoped: true
})
export class SCntMonobankTopMenu {
  /**
   * Данные для верхнего меню
   */
  @Prop() topMenuList: MonobankTopMenuListInterface[];

  /**
   * Список языков
   */
  @Prop() langList:  MonobankLangListInterface[];

  /**
   * Клик по пунктам мобильного меню
   */
  @Event() clickOnTopMenuItem: EventEmitter;

  /**
   * Клик по языка селектора
   */
  @Event() clickOnLangListItem: EventEmitter;

  render() {
    return (
      <div class="top-menu-wrapper">
        <div class="top-menu">
          <div class="top-menu-nav-wrapper">
            <div class="top-menu-nav">
              <nav>
                <ul class="top-menu-list">
                  <TopMenuListFunctionalComponent
                    array={this.topMenuList}
                    clickOnTopMenuItemHandler={(item) => this.clickOnTopMenuItemHandler(item)}
                  />
                </ul>
                <div class="lang-selector-wrapper lang-selector-with-dropdown">
                  <div class="lang-selector-wrapper-inner">
                    <s-cnt-monobank-lang-selector theme={"top"} langList={this.langList}/>
                  </div>
                </div>
              </nav>
            </div>
          </div>
        </div>
      </div>
    );
  }

  /**
   *
   */
  public clickOnTopMenuItemHandler(item) {
    this.clickOnTopMenuItem.emit(item)
  }

}

const TopMenuListFunctionalComponent = props => {
  return props.array.map(item => {
    return (
      <li onClick={(item) => props.clickOnTopMenuItemHandler(item)}>
        <a>{item.item}</a>
      </li>
    );
  });
};
